==> llvm-toolchain-3.7_3.7.1.orig-lldb.tar.bz2: lldb_3.7.1~+final/source/Plugins/ABI/SysV-arm/ABISysV_arm.h <==
//===-- ABISysV_arm.h ----------------------------------------*- C++ -*-===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef liblldb_ABISysV_arm_h_
#define liblldb_ABISysV_arm_h_

// C Includes
// C++ Includes
// Other libraries and framework includes
// Project includes
#include "lldb/lldb-private.h"
#include "lldb/Target/ABI.h"

class ABISysV_arm : public lldb_private::ABI
{
public:
    ~ABISysV_arm() { }

    size_t
    GetRedZoneSize () const override;

    bool
    PrepareTrivialCall (lldb_private::Thread &thread, 
                        lldb::addr_t sp,
                        lldb::addr_t func_addr,
                        lldb::addr_t returnAddress, 
                        llvm::ArrayRef<lldb::addr_t> args) const override;

    bool
    GetArgumentValues (lldb_private::Thread &thread,
                       lldb_private::ValueList &values) const override;

    lldb_private::Error
    SetReturnValueObject(lldb::StackFrameSP &frame_sp, lldb::ValueObjectSP &new_value) override;

protected:
    lldb::ValueObjectSP
    GetReturnValueObjectImpl (lldb_private::Thread &thread,
                    lldb_private::ClangASTType &ast_type) const override;

public:
    bool
    CreateFunctionEntryUnwindPlan (lldb_private::UnwindPlan &unwind_plan) override;

    bool
    CreateDefaultUnwindPlan (lldb_private::UnwindPlan &unwind_plan) override;
    
    bool
    RegisterIsVolatile (const lldb_private::RegisterInfo *reg_info) override;

    bool
    CallFrameAddressIsValid (lldb::addr_t cfa) override
    {
        // Make sure the stack call frame addresses are are 4 byte aligned
        if (cfa & (4ull - 1ull))
            return false;   // Not 4 byte aligned
        if (cfa == 0)
            return false;   // Zero is not a valid stack address
        return true;
    }
    
    bool
    CodeAddressIsValid (lldb::addr_t pc) override
    {
        // Just make sure the address is a valid 32 bit address. Bit zero
        // might be set due to Thumb function calls, so don't enforce 2 byte
        // alignment
        return pc <= UINT32_MAX;
    }
    
    lldb::addr_t
    FixCodeAddress (lldb::addr_t pc) override
    {
        // ARM uses bit zero to signify a code address is thumb, so we must
        // strip bit zero in any code addresses.
        return pc & ~(lldb::addr_t)1;
    }

    const lldb_private::RegisterInfo *
    GetRegisterInfoArray (uint32_t &count) override;

    //------------------------------------------------------------------
    // Static Functions
    //------------------------------------------------------------------
    static void
    Initialize();
    
    static void
    Terminate();
    
    static lldb::ABISP
    CreateInstance (const lldb_private::ArchSpec &arch);
    
    static lldb_private::ConstString
    GetPluginNameStatic();
    
    //------------------------------------------------------------------
    // PluginInterface protocol
    //------------------------------------------------------------------
    lldb_private::ConstString
    GetPluginName() override;
    
    uint32_t
    GetPluginVersion() override;
    
protected:
private:
    ABISysV_arm() : 
        lldb_private::ABI() 
    {
         // Call CreateInstance instead.
    }
};

#endif  // liblldb_ABISysV_arm_h_

==> llvm-toolchain-3.8_3.8.1.orig-lldb.tar.bz2: lldb_3.8~+final/source/Plugins/ABI/SysV-arm/ABISysV_arm.h <==
//===-- ABISysV_arm.h ----------------------------------------*- C++ -*-===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef liblldb_ABISysV_arm_h_
#define liblldb_ABISysV_arm_h_

// C Includes
// C++ Includes
// Other libraries and framework includes
// Project includes
#include "lldb/lldb-private.h"
#include "lldb/Target/ABI.h"

class ABISysV_arm : public lldb_private::ABI
{
public:
    ~ABISysV_arm() override = default;

    size_t
    GetRedZoneSize () const override;

    bool
    PrepareTrivialCall (lldb_private::Thread &thread, 
                        lldb::addr_t sp,
                        lldb::addr_t func_addr,
                        lldb::addr_t returnAddress, 
                        llvm::ArrayRef<lldb::addr_t> args) const override;

    bool
    GetArgumentValues (lldb_private::Thread &thread,
                       lldb_private::ValueList &values) const override;

    lldb_private::Error
    SetReturnValueObject(lldb::StackFrameSP &frame_sp, lldb::ValueObjectSP &new_value) override;

    bool
    CreateFunctionEntryUnwindPlan (lldb_private::UnwindPlan &unwind_plan) override;

    bool
    CreateDefaultUnwindPlan (lldb_private::UnwindPlan &unwind_plan) override;
    
    bool
    RegisterIsVolatile (const lldb_private::RegisterInfo *reg_info) override;

    bool
    CallFrameAddressIsValid (lldb::addr_t cfa) override
    {
        // Make sure the stack call frame addresses are are 4 byte aligned
        if (cfa & (4ull - 1ull))
            return false;   // Not 4 byte aligned
        if (cfa == 0)
            return false;   // Zero is not a valid stack address
        return true;
    }
    
    bool
    CodeAddressIsValid (lldb::addr_t pc) override
    {
        // Just make sure the address is a valid 32 bit address. Bit zero
        // might be set due to Thumb function calls, so don't enforce 2 byte
        // alignment
        return pc <= UINT32_MAX;
    }
    
    lldb::addr_t
    FixCodeAddress (lldb::addr_t pc) override
    {
        // ARM uses bit zero to signify a code address is thumb, so we must
        // strip bit zero in any code addresses.
        return pc & ~(lldb::addr_t)1;
    }

    const lldb_private::RegisterInfo *
    GetRegisterInfoArray (uint32_t &count) override;

    //------------------------------------------------------------------
    // Static Functions
    //------------------------------------------------------------------

    static void
    Initialize();
    
    static void
    Terminate();
    
    static lldb::ABISP
    CreateInstance (const lldb_private::ArchSpec &arch);
    
    static lldb_private::ConstString
    GetPluginNameStatic();
    
    //------------------------------------------------------------------
    // PluginInterface protocol
    //------------------------------------------------------------------

    lldb_private::ConstString
    GetPluginName() override;
    
    uint32_t
    GetPluginVersion() override;
    
protected:
    lldb::ValueObjectSP
    GetReturnValueObjectImpl(lldb_private::Thread &thread,
                             lldb_private::CompilerType &ast_type) const override;

private:
    ABISysV_arm() : 
        lldb_private::ABI() 
    {
         // Call CreateInstance instead.
    }
};

#endif // liblldb_ABISysV_arm_h_
